"use strict";
// Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license.
// See LICENSE in the project root for license information.
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DocsTool = void 0;
const node_core_library_1 = require("@rushstack/node-core-library");
const path_1 = __importDefault(require("path"));
class DocsTool {
    constructor(plugin) {
        this.plugin = plugin;
        this.session = plugin.session;
    }
    // ZOD relies on type inference generate a messy expression in the .d.ts file
    // eslint-disable-next-line @typescript-eslint/explicit-function-return-type
    get schema() {
        const zod = this.session.zod;
        return zod.object({
            userQuery: zod.string().describe('The user query to search for relevant documentation sections.')
        });
    }
    // TODO: replace with Microsoft's service
    _searchDocs(query) {
        const startTime = Date.now();
        const results = node_core_library_1.JsonFile.load(path_1.default.join(__dirname, './rush-doc-fragment.mock.json'));
        return {
            query,
            results,
            count: results.length,
            searchTimeMs: Date.now() - startTime
        };
    }
    async executeAsync({ userQuery }) {
        const docSearchResult = this._searchDocs(userQuery);
        return {
            content: [
                {
                    type: 'text',
                    text: docSearchResult.results.map((item) => item.text).join('\n\n')
                }
            ]
        };
    }
}
exports.DocsTool = DocsTool;
//# sourceMappingURL=DocsTool.js.map